API docs for “spamfighter.txjsonrpc.netstring.test.test_jsonrpc.Test”

# Class s.t.n.t.t.Test(JSONRPC):

Part of spamfighter.txjsonrpc.netstring.test.test_jsonrpc View Source View In Hierarchy

No class docstring

Method | jsonrpc_add | This function add two numbers.
Method | jsonrpc_pair | This function puts the two arguments in an array.
Method | jsonrpc_defer | Help for defer.
Method | jsonrpc_deferFail | Undocumented
Method | jsonrpc_fail | Undocumented
Method | jsonrpc_fault | Undocumented
Method | jsonrpc_deferFault | Undocumented
Method | jsonrpc_complex | Undocumented
Method | jsonrpc_dict | Undocumented
Method | getFunction | Given a string, return a function, or raise NoSuchFunction.

Inherited from JSONRPC:

Method | __init__ | Undocumented
Method | __call__ | Undocumented
Method | connectionMade | Undocumented
Method | putSubHandler | Undocumented
Method | getSubHandler | Undocumented
Method | getSubHandlerPrefixes | Undocumented
Method | stringReceived | Undocumented
Method | _cbDispatch | Undocumented
Method | _cbRender | Undocumented
Method | _ebRender | Undocumented
Method | _listFunctions | Return a list of the names of all jsonrpc methods.

def jsonrpc_add(self, a, b): (source)
This function add two numbers.

def jsonrpc_pair(self, string, num): (source)
This function puts the two arguments in an array.

def jsonrpc_defer(self, x): (source)
Help for defer.

def jsonrpc_deferFail(self): (source)
Undocumented
def jsonrpc_fail(self): (source)
Undocumented
def jsonrpc_fault(self): (source)
Undocumented
def jsonrpc_deferFault(self): (source)
Undocumented
def jsonrpc_complex(self): (source)
Undocumented
def jsonrpc_dict(self, map, key): (source)
Undocumented
def getFunction(self, functionPath): (source)
overrides spamfighter.txjsonrpc.netstring.jsonrpc.JSONRPC.getFunction
Given a string, return a function, or raise NoSuchFunction.

This returned function will be called, and should return the result of the call, a Deferred, or a Fault instance.

Override in subclasses if you want your own policy. The default policy is that given functionPath 'foo', return the method at self.jsonrpc_foo, i.e. getattr(self, "jsonrpc_" + functionPath). If functionPath contains self.separator, the sub-handler for the initial prefix is used to search for the remaining path.